package protocolP2P;
import java.util.ArrayList;
import protocolP2P.Payload;
import protocolP2P.RequestResponseCode;
import exception.ProtocolError;
import exception.InternalError;
import exception.SizeError;

/** Representation of payload for list response.
 * @author	Louis Royer
 * @author	Flavien Haas
 * @author	JS Auge
 * @version	1.0
 */
public class FileList extends Payload {
	private ArrayList<String> content;

	/** Constructor (typically used by the server) with an ArrayList parameter containing
	 * filenames.
	 * @param content	a list of files. Must not be empty.
	 * @throws	InternalError
	 */
	public FileList(ArrayList<String> content) throws InternalError {
		super(RequestResponseCode.LIST_RESPONSE);
		/* assert to help debugging */
		assert !content.isEmpty() : "Payload size of FileList must not be empty, use EmptyDirectory from Payload instead";
		if (content.isEmpty()) {
			throw new InternalError();
		}
		this.content = content;
	}

	/** Constructor (typically used by client) with a byte[] parameter containing the datagram received.
	 * @param datagram	the full datagram received
	 * @throws	SizeError
	 * @throws	InternalError
	 * @throws	ProtocolError
	 */
	protected FileList(byte[] datagram) throws SizeError, ProtocolError, InternalError {
		super(datagram);
		/* assert to help debugging */
		assert requestResponseCode == RequestResponseCode.LIST_RESPONSE : "FileList subclass is incompatible with this datagram, request/response code must be checked before using this constructor";
		/* InternalErrorException */
		if (requestResponseCode!= RequestResponseCode.LIST_RESPONSE) {
			throw new InternalError();
		}
		int size = getPayloadSize(datagram);
		//TODO
	}

	/** Returns a byte[] containing datagram with padding.
	 * This datagram is still incomplete and should not be send directly.
	 * ProtocolP2PDatagram will use this method to generate the complete datagram.
	 * @return datagram with padding
	 * @throws	InternalError
	 */
	/*protected byte[] toDatagram() throws InternalError {
		//TODO compute size
		int size = 8 + ;
		byte[] datagram = new byte[size]; // java initialize all to zero
		// size is keep blank (ProtocolP2PDatagram will handle it)
		// set request/response code
		datagram[RequestResponseCode.RRCODE_POSITION] = requestResponseCode.codeValue;
		// bits 16-31 are reserved for future use
		datagram = setPayloadSize(size, datagram);
		//TODO Write content
	}*/
}
